@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Time    : 2021-07-30 20:14
 # @Author  : zbmain
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 __author__ = 'winwin'
 
 from . import env
@@ -9,6 +9,6 @@ from .utils import func_util
 from .utils import os_util
 from .utils import str_util
 from .utils import support
-from .utils.func_util import ps_df
+from .utils.func_util import view_df
 
-__all__ = ['env', 'support', 'os_util', 'str_util', 'func_util', 'ps_df']
+__all__ = ['env', 'support', 'os_util', 'str_util', 'func_util', 'view_df']
