@@ -4,6 +4,8 @@
 
 import time
 
+import pandas
+
 
 def delay(second: int):
     time.sleep(second)
@@ -18,7 +20,7 @@ def delay(second: int):
     return wrapper
 
 
-def ps_df(df, head_num: int = 5, tail_num: int = 5, comment: str = 'DataFrame'):
+def view_df(df: pandas.DataFrame, head_num: int = 5, tail_num: int = 5, comment: str = 'DataFrame'):
     print('%s row_size:%d' % (comment, len(df.index)))
     return df.head(head_num).append(df.tail(tail_num))
 
@@ -43,4 +45,3 @@ def set_seed(seed: int = 1990):
         tensorflow.random.set_seed(seed)
     except:
         pass
-
